@@ -1,3 +1,6 @@
+# frozen_string_literal: true
+require 'arel/errors'
+
 require 'arel/crud'
 require 'arel/factory_methods'
 
@@ -21,7 +24,7 @@ require 'arel/delete_manager'
 require 'arel/nodes'
 
 module Arel
-  VERSION = '6.0.4'
+  VERSION = '9.0.0'
 
   def self.sql raw_sql
     Arel::Nodes::SqlLiteral.new raw_sql
