@@ -1,13 +1,11 @@
+# frozen_string_literal: true
 module Arel
   module Nodes
     class And < Arel::Nodes::Node
       attr_reader :children
 
-      def initialize children, right = nil
-        unless Array === children
-          warn "(#{caller.first}) AND nodes should be created with a list"
-          children = [children, right]
-        end
+      def initialize children
+        super()
         @children = children
       end
 
