@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Arel
   module Visitors
     class Dot < Arel::Visitors::Visitor
@@ -69,6 +70,10 @@ module Arel
         visit_edge o, "expr"
       end
       alias :visit_Arel_Nodes_Group             :unary
+      alias :visit_Arel_Nodes_Cube              :unary
+      alias :visit_Arel_Nodes_RollUp            :unary
+      alias :visit_Arel_Nodes_GroupingSet       :unary
+      alias :visit_Arel_Nodes_GroupingElement   :unary
       alias :visit_Arel_Nodes_Grouping          :unary
       alias :visit_Arel_Nodes_Having            :unary
       alias :visit_Arel_Nodes_Limit             :unary
@@ -151,6 +156,11 @@ module Arel
         visit_edge o, "name"
       end
 
+      def visit_Arel_Nodes_Casted o
+        visit_edge o, 'val'
+        visit_edge o, 'attribute'
+      end
+
       def visit_Arel_Attribute o
         visit_edge o, "relation"
         visit_edge o, "name"
@@ -176,6 +186,7 @@ module Arel
       alias :visit_Arel_Nodes_As                 :binary
       alias :visit_Arel_Nodes_Assignment         :binary
       alias :visit_Arel_Nodes_Between            :binary
+      alias :visit_Arel_Nodes_Concat             :binary
       alias :visit_Arel_Nodes_DoesNotMatch       :binary
       alias :visit_Arel_Nodes_Equality           :binary
       alias :visit_Arel_Nodes_GreaterThan        :binary
@@ -199,13 +210,15 @@ module Arel
       alias :visit_NilClass :visit_String
       alias :visit_TrueClass :visit_String
       alias :visit_FalseClass :visit_String
-      alias :visit_Arel_Nodes_BindParam :visit_String
+      alias :visit_Integer :visit_String
       alias :visit_Fixnum :visit_String
       alias :visit_BigDecimal :visit_String
       alias :visit_Float :visit_String
       alias :visit_Symbol :visit_String
       alias :visit_Arel_Nodes_SqlLiteral :visit_String
 
+      def visit_Arel_Nodes_BindParam o; end
+
       def visit_Hash o
         o.each_with_index do |pair, i|
           edge("pair_#{i}")   { visit pair }
@@ -265,7 +278,7 @@ module Arel
             label = "<f0>#{node.name}"
 
             node.fields.each_with_index do |field, i|
-              label << "|<f#{i + 1}>#{quote field}"
+              label += "|<f#{i + 1}>#{quote field}"
             end
 
             "#{node.id} [label=\"#{label}\"];"
