@@ -1,27 +1,36 @@
+# frozen_string_literal: true
 module Arel
   module Visitors
     class Visitor
+      def initialize
+        @dispatch = get_dispatch_cache
+      end
+
       def accept object
         visit object
       end
 
       private
 
-      DISPATCH = Hash.new do |hash, visitor_class|
-        hash[visitor_class] =
-          Hash.new do |method_hash, node_class|
-            method_hash[node_class] = "visit_#{(node_class.name || '').gsub('::', '_')}"
-          end
+      def self.dispatch_cache
+        Hash.new do |hash, klass|
+          hash[klass] = "visit_#{(klass.name || '').gsub('::', '_')}"
+        end
+      end
+
+      def get_dispatch_cache
+        self.class.dispatch_cache
       end
 
       def dispatch
-        DISPATCH[self.class]
+        @dispatch
       end
 
-      def visit object, attribute = nil
-        send dispatch[object.class], object, attribute
+      def visit object
+        dispatch_method = dispatch[object.class]
+        send dispatch_method, object
       rescue NoMethodError => e
-        raise e if respond_to?(dispatch[object.class], true)
+        raise e if respond_to?(dispatch_method, true)
         superklass = object.class.ancestors.find { |klass|
           respond_to?(dispatch[klass], true)
         }
